@@ -44,7 +44,9 @@ calc_ete <- function(x, y, lx = 1, ly = 1, q = 0.1,
                      limits = NULL,
                      burn = 50,
                      seed = NULL) {
-  calc_te_ete("ete", x, y, lx = lx, ly = ly, entropy = entropy, q = q,
-              shuffles = shuffles, type = type, quantiles = quantiles,
-              bins = bins, limits = limits, burn = burn, seed = seed)
+  calc_te_ete("ete", x, y,
+    lx = lx, ly = ly, entropy = entropy, q = q,
+    shuffles = shuffles, type = type, quantiles = quantiles,
+    bins = bins, limits = limits, burn = burn, seed = seed
+  )
 }
